import os
import unittest

from ..yaml import load

current_dir = os.path.dirname(os.path.realpath(__file__))
fixtures_path = "{}/fixtures".format(current_dir)


def test_load():
    expected = {"foo": "bar"}
    got = load("{}/test_load.yaml".format(fixtures_path))
    assert expected == got



import sys
from .yaml import load, dump


def load_or_die(file_path):
    try:
        return load(file_path)
    except FileNotFoundError:
        print("{} file does not exists".format(file_path))
        sys.exit(1)


def main():
    meta_requirements_path = "meta/{}".format("main.yml")
    requirements_path = "requirements.yml"

    requirements = load_or_die(requirements_path)
    meta_requirements = load_or_die(meta_requirements_path)

    if 'dependencies' not in meta_requirements:
        print(
            "Format Error - Ansible Galaxy {} file does not contain main dependencies list".format(meta_requirements_path))
        sys.exit(1)

    print("Appending {} content into {} dependencies".format(
        requirements_path, meta_requirements_path))
    meta_requirements['dependencies'] = requirements
    dump(meta_requirements_path, meta_requirements)


if __name__ == "__main__":
    main()



import yaml

requirements = {}
meta = {}


def load(path):
    """Reads the yaml file and returns the content """
    with open(path, 'r') as stream:
        return yaml.load(stream)


def dump(path, content):
    """ Writes the yaml content into the file """
    with open(path, mode='w') as stream:
        yaml.dump(content, stream)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="molecule-galaxy-wrapper",
    version="0.0.1",
    author="Bernardo Vale",
    author_email="bernardosilveiravale@gmail.com",
    description="A wrapper for ansible-galaxy that allows you to define role dependencies inside a requirements.yml",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bernardoVale/molecule-galaxy-wrapper",
    packages=setuptools.find_packages(),
    scripts=[
        "bin/galaxywrapper"
    ],
    entry_points={
        'console_scripts': ['molecule-galaxy-wrapper=molecule_wrapper.cli:main'],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
